package com.dcs.hnyz.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.dcs.hnyz.domain.ScreenSettings;
import com.dcs.hnyz.domain.vo.ScreenSettingsFormVO;

/**
 * 大屏设置管理Mapper接口
 * 
 * @author hmy
 * @date 2025-04-30
 */
public interface ScreenSettingsMapper extends BaseMapper<ScreenSettings>
{
    /**
     * 查询大屏设置管理
     * 
     * @param id 大屏设置管理主键
     * @return 大屏设置管理
     */
    public ScreenSettings selectScreenSettingsById(Long id);

    /**
     * 查询大屏设置管理列表
     * 
     * @param screenSettings 大屏设置管理
     * @return 大屏设置管理集合
     */
    public List<ScreenSettings> selectScreenSettingsList(ScreenSettings screenSettings);

    /**
     * 新增大屏设置管理
     * 
     * @param screenSettings 大屏设置管理
     * @return 结果
     */
    public int insertScreenSettings(ScreenSettings screenSettings);

    /**
     * 修改大屏设置管理
     * 
     * @param screenSettings 大屏设置管理
     * @return 结果
     */
    public int updateScreenSettings(ScreenSettings screenSettings);

    /**
     * 删除大屏设置管理
     * 
     * @param id 大屏设置管理主键
     * @return 结果
     */
    public int deleteScreenSettingsById(Long id);

    /**
     * 批量删除大屏设置管理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteScreenSettingsByIds(Long[] ids);

    /**
     * 查询大屏设置表单管理列表
     * @param screenSettings
     * @return
     */
    List<ScreenSettingsFormVO> selectScreenSettingsFormList(ScreenSettings screenSettings);
}
